BEGIN;

CREATE SEQUENCE account_id_seq;

CREATE TABLE account (
  ID INT4 DEFAULT nextval('account_id_seq'),
  AccountNumber INT4 NOT NULL DEFAULT '0',
  name varchar(128) NOT NULL DEFAULT '',
  title INT4 NOT NULL DEFAULT '0',
  gref INT4 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE accountheading_id_seq;

CREATE TABLE accountheading (
  ID INT4 DEFAULT nextval('accountheading_id_seq'),
  name varchar(128) NOT NULL DEFAULT '',
  sref INT4 NOT NULL DEFAULT '0',
  eref INT4 NOT NULL DEFAULT '0',
  gref INT4 NOT NULL DEFAULT '0',
  type INT2 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID),
  CHECK (type>=0 AND type < 5)
);

-- --------------------------------------------------------

CREATE SEQUENCE address_id_seq;

CREATE TABLE address (
  ID INT4 DEFAULT nextval('address_id_seq'),
  Address1 varchar(128) NOT NULL DEFAULT 'No Name',
  Address2 varchar(128) NOT NULL DEFAULT 'No Name',
  Address3 varchar(128) NOT NULL DEFAULT 'No Name',
  City varchar(64) NOT NULL DEFAULT 'No Name',
  State varchar(32) NOT NULL DEFAULT '',
  PostCode varchar(32) NOT NULL DEFAULT 'No Name',
  Country varchar(64) NOT NULL DEFAULT 'No Name',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE adjustment_id_seq;

CREATE TABLE adjustment (
  ID INT4 DEFAULT nextval('adjustment_id_seq'),
  Name varchar(64) NOT NULL DEFAULT '',
  EnteredAt timestamp NOT NULL,
  stationID varchar(20) NOT NULL DEFAULT '',
  userID INT4 NOT NULL DEFAULT '0',
  typeID INT4 NOT NULL DEFAULT '0',
  amount FLOAT8 NOT NULL DEFAULT '0',
  data varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE adjustmenttype_id_seq;

CREATE TABLE adjustmenttype (
  ID INT4 DEFAULT nextval('adjustmenttype_id_seq'),
  Name varchar(64) NOT NULL DEFAULT '',
  Active char(1) NOT NULL DEFAULT 'N',
  PRIMARY KEY (ID),
  CHECK (Active='N' OR Active='Y')
);

-- --------------------------------------------------------

CREATE SEQUENCE authority_id_seq;

CREATE TABLE authority (
  ID INT4 DEFAULT nextval('authority_id_seq'),
  Name char(64) NOT NULL DEFAULT '',
  Description char(255) NOT NULL DEFAULT '',
  perm_login char(1) NOT NULL DEFAULT 'N',
  perm_list char(1) NOT NULL DEFAULT 'N',
  perm_browse char(1) NOT NULL DEFAULT 'N',
  perm_add char(1) NOT NULL DEFAULT 'N',
  perm_edit char(1) NOT NULL DEFAULT 'N',
  perm_delete char(1) NOT NULL DEFAULT 'N',
  perm_shutdown char(1) NOT NULL DEFAULT 'N',
  PRIMARY KEY (ID),
  CHECK (perm_login='N' OR perm_login='Y'),
  CHECK (perm_list='N' OR perm_list='Y'),
  CHECK (perm_browse='N' OR perm_browse='Y'),
  CHECK (perm_add='N' OR perm_add='Y'),
  CHECK (perm_edit='N' OR perm_edit='Y'),
  CHECK (perm_delete='N' OR perm_delete='Y'),
  CHECK (perm_shutdown='N' OR perm_shutdown='Y')
);

CREATE TABLE badcheque (
  ID INT4 NOT NULL DEFAULT '0',
  chequeID INT4 NOT NULL DEFAULT '0',
  addedBy INT4 NOT NULL DEFAULT '0',
  addedDate DATE NOT NULL DEFAULT '0001-01-01',
  name varchar(128) NOT NULL DEFAULT '',
  chequeStart varchar(32) NOT NULL DEFAULT '',
  chequeEnd varchar(32) NOT NULL DEFAULT '',
  bankData varchar(128) NOT NULL DEFAULT '',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE bankdetails_id_seq;

CREATE TABLE bankdetails (
  ID INT4 DEFAULT nextval('bankdetails_id_seq'),
  bankID INT4 NOT NULL DEFAULT '0',
  accountID INT4 NOT NULL DEFAULT '0',
  name varchar(64) NOT NULL DEFAULT '',
  branch varchar(64) NOT NULL DEFAULT '',
  addressID INT4 NOT NULL DEFAULT '0',
  contactID INT4 NOT NULL DEFAULT '0',
  BankSortCode varchar(32) NOT NULL DEFAULT '',
  BankNumber varchar(32) NOT NULL DEFAULT '',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE bankitem_id_seq;

CREATE TABLE bankitem (
  ID INT4 DEFAULT nextval('bankitem_id_seq'),
  bankID INT4 NOT NULL DEFAULT '0',
  itemdate DATE NOT NULL DEFAULT '0001-01-01',
  itemtype INT4 NOT NULL DEFAULT '0',
  accountID INT4 NOT NULL DEFAULT '0',
  transID INT4 NOT NULL DEFAULT '0',
  referencedata varchar(32) NOT NULL DEFAULT '',
  Amount FLOAT8 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE bankitemtype_id_seq;

CREATE TABLE bankitemtype (
  ID INT4 DEFAULT nextval('bankitemtype_id_seq'),
  name varchar(64) NOT NULL DEFAULT '',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE bqname_id_seq;

CREATE TABLE bqname (
  ID INT4 DEFAULT nextval('bqname_id_seq'),
  name varchar(64) NOT NULL DEFAULT '',
  accountID INT4 NOT NULL DEFAULT '0',
  OnMenu char(1) NOT NULL DEFAULT 'N',
  PRIMARY KEY (ID),
  CHECK (OnMenu='N' OR OnMenu='Y')
);

-- --------------------------------------------------------

CREATE SEQUENCE category_id_seq;

CREATE TABLE category (
  ID INT4 DEFAULT nextval('category_id_seq'),
  parentID INT4 NOT NULL DEFAULT '0',
  name varchar(32) NOT NULL DEFAULT '',
  description varchar(128) NOT NULL DEFAULT '',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE chargeaccount_id_seq;

CREATE TABLE chargeaccount (
  ID INT4 DEFAULT nextval('chargeaccount_id_seq'),
  chargeID INT4 NOT NULL DEFAULT '0',
  cmid INT4 NOT NULL DEFAULT '0',
  typeID INT4 NOT NULL DEFAULT '0',
  creditlimit DECIMAL(6,2) NOT NULL DEFAULT '0.00',
  lasttransaction DATE NOT NULL DEFAULT '0001-01-01',
  accountID varchar(32) NOT NULL DEFAULT '0',
  standardTerms char(1) NOT NULL DEFAULT 'N',
  CODTerms char(1) NOT NULL DEFAULT 'N',
  prepaidTerms char(1) NOT NULL DEFAULT 'N',
  termsType char(1) NOT NULL DEFAULT 'N',
  dueMonthEnd char(1) NOT NULL DEFAULT 'N',
  dueDays INT4 NOT NULL DEFAULT '0',
  discountDays INT4 NOT NULL DEFAULT '0',
  discount DECIMAL(6,2) NOT NULL DEFAULT '0.00',
  Notes varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (ID),
  CHECK (standardTerms='N' OR standardTerms='Y'),
  CHECK (CODTerms='N' OR CODTerms='Y'),
  CHECK (prepaidTerms='N' OR prepaidTerms='Y'),
  CHECK (termsType='N' OR termsType='Y'),
  CHECK (dueMonthEnd='N' OR dueMonthEnd='Y')
);

-- --------------------------------------------------------

CREATE SEQUENCE chargeacctype_id_seq;

CREATE TABLE chargeacctype (
  ID INT4 DEFAULT nextval('chargeaccount_id_seq'),
  name VARCHAR(32) NOT NULL,
  PRIMARY KEY (ID)
); 

-- --------------------------------------------------------

CREATE SEQUENCE class_id_seq;

CREATE TABLE class (
  ID INT4 DEFAULT nextval('class_id_seq'),
  classID INT4 NOT NULL DEFAULT '0',
  sdate DATE NOT NULL DEFAULT '0001-01-01',
  edate DATE NOT NULL DEFAULT '0001-01-01',
  minnumber INT4 NOT NULL DEFAULT '1',
  maxnumber INT4 NOT NULL DEFAULT '1',
  name varchar(64) NOT NULL DEFAULT '',
  description varchar(255) NOT NULL DEFAULT '',
  restrictions varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE collection_id_seq;

CREATE TABLE collection (
  ID INT4 DEFAULT nextval('collection_id_seq'),
  name varchar(32) NOT NULL DEFAULT '',
  description varchar(64) NOT NULL DEFAULT '',
  collectionID INT4 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE contactdetails_id_seq;

CREATE TABLE contactdetails (
  ID INT4 DEFAULT nextval('contactdetails_id_seq'),
  ContactDetailsID INT4 NOT NULL DEFAULT '0',
  type INT4 NOT NULL DEFAULT '0',
  data varchar(64) NOT NULL DEFAULT '0',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE contacts_id_seq;

CREATE TABLE contacts (
  ID INT4 DEFAULT nextval('contacts_id_seq'),
  ContactID INT4 NOT NULL DEFAULT '0',
  ContactDetailsID INT4 NOT NULL DEFAULT '0',
  title varchar(32) NOT NULL DEFAULT '',
  FirstName varchar(32) NOT NULL DEFAULT 'No Name',
  LastName varchar(64) NOT NULL DEFAULT 'No Name',
  middleinitial char(1) NOT NULL DEFAULT '',
  LastContact DATE NOT NULL DEFAULT '0001-01-01',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE country_id_seq;

CREATE TABLE country (
  ID INT2 DEFAULT nextval('country_id_seq'),
  cid INT2 NOT NULL DEFAULT '0',
  name char(64) NOT NULL DEFAULT '',
  ISOname char(4) NOT NULL DEFAULT '',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE course_id_seq;

CREATE TABLE course (
  ID INT4 DEFAULT nextval('course_id_seq'),
  courseID INT4 NOT NULL DEFAULT '0',
  sdate DATE NOT NULL DEFAULT '0001-01-01',
  edate DATE NOT NULL DEFAULT '0001-01-01',
  minnumber INT4 NOT NULL DEFAULT '1',
  maxnumber INT4 NOT NULL DEFAULT '1',
  name varchar(64) NOT NULL DEFAULT '',
  description varchar(255) NOT NULL DEFAULT '',
  restrictions varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE createmod_id_seq;

CREATE TABLE createmod (
  ID INT4 DEFAULT nextval('createmod_id_seq'),
  CreationDate DATE NOT NULL DEFAULT '0001-01-01',
  ModifiedDate DATE NOT NULL DEFAULT '0001-01-01',
  CreatedBy INT4 NOT NULL DEFAULT '0',
  ModifiedBy INT4 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE currency_id_seq;

CREATE TABLE currency (
  ID INT2 DEFAULT nextval('currency_id_seq'),
  CountryID INT2 NOT NULL DEFAULT '0',
  Country char(32) NOT NULL DEFAULT '',
  BigName char(32) NOT NULL DEFAULT '',
  ISOName char(4) NOT NULL DEFAULT '',
  ISONumber INT2 NOT NULL DEFAULT '0',
  MonetaryUnitsID INT4 NOT NULL DEFAULT '1',
  SmallName char(32) NOT NULL DEFAULT '',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE custcallhistory_id_seq;

CREATE TABLE custcallhistory (
  ID INT4 DEFAULT nextval('custcallhistory_id_seq'),
  custID INT4 NOT NULL DEFAULT '0',
  cdate DATE NOT NULL DEFAULT '0001-01-01',
  Caller char(64) NOT NULL DEFAULT '',
  Subject char(64) DEFAULT NULL,
  Details char(64) DEFAULT NULL,
  ActionID INT4 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE custflags_id_seq;

CREATE TABLE custflags (
  ID INT4 DEFAULT nextval('custflags_id_seq'),
  custID INT4 NOT NULL DEFAULT '0',
  edate DATE NOT NULL DEFAULT '0001-01-01',
  Notes varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE custhistory_id_seq;

CREATE TABLE custhistory (
  ID INT4 DEFAULT nextval('custhistory_id_seq'),
  custID INT4 NOT NULL DEFAULT '0',
  transID INT4 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE custinterventionhistory_id_seq;

CREATE TABLE custinterventionhistory (
  ID INT4 DEFAULT nextval('custinterventionhistory_id_seq'),
  custID INT4 NOT NULL DEFAULT '0',
  ContactWhoID INT4 NOT NULL DEFAULT '0',
  ContactTime timestamp NOT NULL,
  OutTime timestamp NOT NULL,
  ArriveTime timestamp NOT NULL,
  LeaveTime timestamp NOT NULL,
  Cause char(64) NOT NULL DEFAULT '',
  Cure char(64) NOT NULL DEFAULT '',
  Billed char(1) NOT NULL DEFAULT 'N',
  InterventistID INT4 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID),
  CHECK (Billed='N' OR Billed='Y')
);

-- --------------------------------------------------------

CREATE SEQUENCE customer_id_seq;

CREATE TABLE customer (
  ID INT4 DEFAULT nextval('customer_id_seq'),
  cmid INT4 NOT NULL DEFAULT '0',
  contactID INT4 NOT NULL DEFAULT '0',
  addressID INT4 NOT NULL DEFAULT '0',
  storecardID INT4 NOT NULL DEFAULT '0',
  loyalityID INT4 NOT NULL DEFAULT '0',
  signatureID INT4 NOT NULL DEFAULT '0',
  chargeAccountID INT4 NOT NULL DEFAULT '0',
  Notes varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE delivery_id_seq;

CREATE TABLE delivery (
  ID INT4 DEFAULT nextval('delivery_id_seq'),
  cmid INT4 NOT NULL DEFAULT '0',
  delivererID INT4 NOT NULL DEFAULT '0',
  customerID INT4 NOT NULL DEFAULT '0',
  transactionID INT4 NOT NULL DEFAULT '0',
  status INT4 NOT NULL DEFAULT '0',
  amount float NOT NULL DEFAULT '0',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE departments_id_seq;

CREATE TABLE departments (
  ID INT4 DEFAULT nextval('departments_id_seq'),
  deptID INT4 NOT NULL DEFAULT '0',
  name char(32) NOT NULL DEFAULT '',
  siteID INT4 NOT NULL DEFAULT '0',
  AnnualBudget DECIMAL(6,2) NOT NULL DEFAULT '0.00',
  headID INT4 NOT NULL DEFAULT '0',
  localeID INT4 NOT NULL DEFAULT '0',
  currencyID INT4 NOT NULL DEFAULT '0',
  Active char(1) NOT NULL DEFAULT 'N',
  PRIMARY KEY (ID),
  CHECK (Active='N' OR Active='Y')
);

-- --------------------------------------------------------

CREATE SEQUENCE deposit_id_seq;

CREATE TABLE deposit (
  ID INT4 DEFAULT nextval('deposit_id_seq'),
  depositID INT4 NOT NULL DEFAULT '0',
  cmid INT4 NOT NULL DEFAULT '0',
  name varchar(32) NOT NULL DEFAULT '',
  percentage FLOAT8 NOT NULL DEFAULT '0',
  refundable char(1) NOT NULL DEFAULT 'N',
  type INT4 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID),
  CHECK (refundable='N' OR refundable='Y')
);

-- --------------------------------------------------------

CREATE SEQUENCE discount_id_seq;

CREATE TABLE discount (
  ID INT4 DEFAULT nextval('discount_id_seq'),
  DiscountID varchar(16) NOT NULL DEFAULT '',
  type INT4 NOT NULL DEFAULT '0',
  ident INT4 NOT NULL DEFAULT '0',
  targetID INT4 NOT NULL DEFAULT '0',
  Margin FLOAT8 NOT NULL DEFAULT '0',
  Status varchar(64) NOT NULL DEFAULT '',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE discreetdiscount_id_seq;

CREATE TABLE discreetdiscount (
  ID INT4 DEFAULT nextval('discreetdiscount_id_seq'),
  transactionID INT4 NOT NULL DEFAULT '0',
  userID INT4 NOT NULL DEFAULT '0',
  stationID varchar(20) NOT NULL DEFAULT '0',
  type INT4 NOT NULL DEFAULT '0',
  PLU varchar(16) NOT NULL DEFAULT '',
  margin float NOT NULL DEFAULT '1',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE discrepancy_id_seq;

CREATE TABLE discrepancy (
  ID INT4 DEFAULT nextval('discrepancy_id_seq'),
  Name varchar(64) NOT NULL DEFAULT '',
  EnteredAt timestamp NOT NULL,
  stationID varchar(20) NOT NULL DEFAULT '',
  userID INT4 NOT NULL DEFAULT '0',
  typeID INT4 NOT NULL DEFAULT '0',
  amount FLOAT8 NOT NULL DEFAULT '0',
  data varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE discrepancytype_id_seq;

CREATE TABLE discrepancytype (
  ID INT4 DEFAULT nextval('discrepancytype_id_seq'),
  Name varchar(64) NOT NULL DEFAULT '',
  Active char(1) NOT NULL DEFAULT 'N',
  PRIMARY KEY (ID),
  CHECK (Active='N' OR Active='Y')
);

-- --------------------------------------------------------

CREATE SEQUENCE doctor_id_seq;

CREATE TABLE doctor (
  ID INT4 DEFAULT nextval('doctor_id_seq'),
  fname varchar(32) NOT NULL DEFAULT '',
  lname varchar(32) NOT NULL DEFAULT '',
  statelicence varchar(32) NOT NULL DEFAULT '',
  DEA varchar(32) NOT NULL DEFAULT '',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE edicaps_id_seq;

CREATE TABLE edicaps (
  ID INT4 DEFAULT nextval('edicaps_id_seq'),
  type varchar(64) NOT NULL DEFAULT '',
  method varchar(64) NOT NULL DEFAULT '',
  interfaceID varchar(64) NOT NULL DEFAULT '',
  handled char(1) NOT NULL DEFAULT 'N',
  PRIMARY KEY (ID),
  CHECK (handled='N' OR handled='Y')
);

-- --------------------------------------------------------

CREATE SEQUENCE employee_id_seq;

CREATE TABLE employee (
  ID INT4 DEFAULT nextval('employee_id_seq'),
  employeeID INT4 NOT NULL DEFAULT '0',
  EmployeeNumber varchar(16) NOT NULL DEFAULT '',
  groupID INT4 NOT NULL DEFAULT '0',
  startdate DATE NOT NULL DEFAULT '0001-01-01',
  enddate DATE NOT NULL DEFAULT '0001-01-01',
  fname varchar(32) NOT NULL DEFAULT '',
  lname varchar(32) NOT NULL DEFAULT '',
  sex char(1) NOT NULL DEFAULT 'M',
  DOB DATE NOT NULL DEFAULT '0001-01-01',
  addressID INT4 NOT NULL DEFAULT '0',
  JobDesc varchar(64) NOT NULL DEFAULT '',
  imageID INT4 NOT NULL DEFAULT '0',
  Paygrade INT4 NOT NULL DEFAULT '0',
  AnnualPay DECIMAL(6,2) NOT NULL DEFAULT '0.00',
  AnnualHols INT4 NOT NULL DEFAULT '0',
  TaxCode varchar(16) NOT NULL DEFAULT '',
  NICode varchar(16) NOT NULL DEFAULT '',
  NInumber varchar(16) NOT NULL DEFAULT '',
  prevTax DECIMAL(6,2) NOT NULL DEFAULT '0.00',
  prevPay DECIMAL(6,2) NOT NULL DEFAULT '0.00',
  bankID INT4 NOT NULL DEFAULT '0',
  Login varchar(16) NOT NULL DEFAULT '',
  Password varchar(16) NOT NULL DEFAULT '',
  Profile varchar(255) NOT NULL DEFAULT '',
  InterfaceAuthID INT4 NOT NULL DEFAULT '0',
  Notes varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (ID),
  CHECK (sex='F' OR sex='M')
);

-- --------------------------------------------------------

CREATE SEQUENCE employeeaction_id_seq;

CREATE TABLE employeeaction (
  ID INT4 DEFAULT nextval('employeeaction_id_seq'),
  name char(32) NOT NULL DEFAULT '',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE employeelog_id_seq;

CREATE TABLE employeelog (
  ID INT4 DEFAULT nextval('employeelog_id_seq'),
  employeeID INT4 NOT NULL DEFAULT '0',
  actionID INT4 NOT NULL DEFAULT '0',
  stamper timestamp NOT NULL,
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE ephemeral_plu_id_seq;

CREATE TABLE ephemeral_plu (
  ID INT4 DEFAULT nextval('ephemeral_plu_id_seq'),
  refID INT4 NOT NULL DEFAULT '0',
  entryat timestamp NOT NULL,
  PLU varchar(128) NOT NULL DEFAULT '',
  PLUType INT4 NOT NULL DEFAULT '0',
  Name varchar(64) NOT NULL DEFAULT 'No Name',
  rectext varchar(64) NOT NULL DEFAULT '',
  UnitPrice FLOAT8 NOT NULL DEFAULT '0',
  Discount float NOT NULL DEFAULT '0',
  Tax float NOT NULL DEFAULT '0',
  type varchar(32) NOT NULL DEFAULT '',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE errorlog_id_seq;

CREATE TABLE errorlog (
  ID INT4 DEFAULT nextval('errorlog_id_seq'),
  IssuedAt timestamp NOT NULL,
  IssuedFrom varchar(20) NOT NULL DEFAULT '',
  IssuedBy INT4 NOT NULL DEFAULT '0',
  AckedAt timestamp NOT NULL,
  TYPE INT4 NOT NULL DEFAULT '0',
  ident INT4 NOT NULL DEFAULT '0',
  Error varchar(64) NOT NULL DEFAULT ''
);

-- --------------------------------------------------------

CREATE SEQUENCE faultlog_id_seq;

CREATE TABLE faultlog (
  ID INT4 DEFAULT nextval('faultlog_id_seq'),
  custID INT4 NOT NULL DEFAULT '0',
  DATE date NOT NULL DEFAULT '0001-01-01',
  memo varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE gaccref_id_seq;

CREATE TABLE gaccref (
  ID INT4 DEFAULT nextval('gaccref_id_seq'),
  AccountNumber varchar(32) NOT NULL DEFAULT '0',
  name varchar(128) NOT NULL DEFAULT '',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE goodstransfer_id_seq;

CREATE TABLE goodstransfer (
  ID INT4 DEFAULT nextval('goodstransfer_id_seq'),
  goodstransferID INT4 NOT NULL DEFAULT '0',
  cmID INT4 NOT NULL DEFAULT '0',
  originator INT4 NOT NULL DEFAULT '0',
  destination INT4 NOT NULL DEFAULT '0',
  status INT4 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE goodstransferitem_id_seq;

CREATE TABLE goodstransferitem (
  ID INT4 DEFAULT nextval('goodstransferitem_id_seq'),
  goodstransferID INT4 NOT NULL DEFAULT '0',
  inventoryID INT4 NOT NULL DEFAULT '0',
  quantity INT4 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE groups_id_seq;

CREATE TABLE groups (
  ID INT4 DEFAULT nextval('groups_id_seq'),
  groupID INT4 NOT NULL DEFAULT '0',
  name char(32) NOT NULL DEFAULT '',
  deptID INT4 NOT NULL DEFAULT '0',
  localeID INT4 NOT NULL DEFAULT '0',
  currencyID INT4 NOT NULL DEFAULT '0',
  Active CHAR(1) NOT NULL DEFAULT 'N',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE imagedata_id_seq;

CREATE TABLE imagedata (
  ID INT4 DEFAULT nextval('imagedata_id_seq'),
  Type INT4 NOT NULL DEFAULT '0',
  RefFile varchar(255) NOT NULL DEFAULT '',
  width INT4 NOT NULL DEFAULT '0',
  height INT4 NOT NULL DEFAULT '0',
  bbp INT4 NOT NULL DEFAULT '0',
  scale INT4 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE insurer_id_seq;

CREATE TABLE insurer (
  ID INT4 DEFAULT nextval('insurer_id_seq'),
  insurerID INT4 NOT NULL DEFAULT '0',
  cmID INT4 NOT NULL DEFAULT '0',
  name varchar(64) NOT NULL DEFAULT '',
  addressID INT4 NOT NULL DEFAULT '0',
  invoiceName varchar(64) NOT NULL DEFAULT '',
  invoiceContactID INT4 NOT NULL DEFAULT '0',
  invoiceAddressID INT4 NOT NULL DEFAULT '0',
  contactID INT4 NOT NULL DEFAULT '0',
  notes varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE interface_id_seq;

CREATE TABLE interface (
  ID INT4 DEFAULT nextval('interface_id_seq'),
  Name varchar(64) NOT NULL DEFAULT '',
  Description varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE inventory_id_seq;

CREATE TABLE inventory (
  ID INT4 DEFAULT nextval('inventory_id_seq'),
  parentID INT4 NOT NULL DEFAULT '0',
  CategoryID INT4 NOT NULL DEFAULT '0',
  PartNumber INT4 NOT NULL DEFAULT '0',
  PartType INT2 NOT NULL DEFAULT '0',
  StockLocation varchar(16) NOT NULL DEFAULT '',
  Description varchar(64) NOT NULL DEFAULT '',
  InStock INT4 NOT NULL DEFAULT '0',
  MaxStock INT4 NOT NULL DEFAULT '0',
  OnOrder INT4 NOT NULL DEFAULT '0',
  ROLevel INT4 NOT NULL DEFAULT '0',
  ROQty INT4 NOT NULL DEFAULT '0',
  ReservedQty INT4 NOT NULL DEFAULT '0',
  LeadTime INT4 NOT NULL DEFAULT '0',
  PartClassification INT4 NOT NULL DEFAULT '0',
  BuyQuantityPriceID INT4 NOT NULL DEFAULT '0',
  CMID INT4 NOT NULL DEFAULT '1',
  invLink INT4 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE invitemquantitytype_id_seq;

CREATE TABLE invitemquantitytype (
  ID INT4 DEFAULT nextval('invitemquantitytype_id_seq'),
  name char(32) NOT NULL DEFAULT '',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE invpricequantity_id_seq;

CREATE TABLE invpricequantity (
  ID INT4 DEFAULT nextval('invpricequantity_id_seq'),
  invprqID INT4 NOT NULL DEFAULT '0',
  nameID INT4 NOT NULL DEFAULT '1',
  Quantity FLOAT8 NOT NULL DEFAULT '1',
  QuantityTypeID INT4 NOT NULL DEFAULT '0',
  UDV INT4 NOT NULL DEFAULT '1',
  Price DECIMAL(14,4) NOT NULL DEFAULT '0.0000',
  baseCurrencyID INT4 NOT NULL DEFAULT '0',
  SupplierID INT4 NOT NULL DEFAULT '0',
  SupplierCode varchar(64) NOT NULL DEFAULT '',
  ediID INT4 NOT NULL DEFAULT '0',
  accountID INT4 NOT NULL DEFAULT '0',
  TaxID INT4 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE itemflags_id_seq;

CREATE TABLE itemflags (
  ID INT4 DEFAULT nextval('itemflags_id_seq'),
  flagID INT4 NOT NULL DEFAULT '0',
  type INT4 NOT NULL DEFAULT '0',
  data varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE label_id_seq;

CREATE TABLE label (
  ID INT4 DEFAULT nextval('label_id_seq'),
  labelID INT4 NOT NULL DEFAULT '0',
  type INT4 NOT NULL DEFAULT '0',
  name varchar(64) NOT NULL DEFAULT '',
  xdim INT4 NOT NULL DEFAULT '0',
  ydim INT4 NOT NULL DEFAULT '0',
  data varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE labelsheet_id_seq;

CREATE TABLE labelsheet (
  ID INT4 DEFAULT nextval('labelsheet_id_seq'),
  name varchar(32) NOT NULL DEFAULT '',
  printsheetID INT4 NOT NULL DEFAULT '0',
  numx INT2 NOT NULL DEFAULT '0',
  numy INT2 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE layby_id_seq;

CREATE TABLE layby (
  ID INT4 DEFAULT nextval('layby_id_seq'),
  orderID INT4 NOT NULL DEFAULT '0',
  orderNumber varchar(64) NOT NULL DEFAULT '',
  customerID INT4 NOT NULL DEFAULT '0',
  transactionID INT4 NOT NULL DEFAULT '0',
  statusID INT4 NOT NULL DEFAULT '0',
  datePlaced DATE NOT NULL DEFAULT '0001-01-01',
  dateRequired DATE NOT NULL DEFAULT '0001-01-01',
  total DECIMAL(6,2) NOT NULL DEFAULT '0.00',
  paid DECIMAL(6,2) NOT NULL DEFAULT '0.00',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE loginmethod_id_seq;

CREATE TABLE loginmethod (
  ID INT4 DEFAULT nextval('loginmethod_id_seq'),
  litdata varchar(4) NOT NULL DEFAULT 'DATA',
  Name varchar(64) NOT NULL DEFAULT '',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE logintypes_id_seq;

CREATE TABLE logintypes (
  ID INT4 DEFAULT nextval('logintypes_id_seq'),
  LoginID INT4 NOT NULL DEFAULT '0',
  Ident varchar(255) NOT NULL DEFAULT '',
  Data varchar(255) NOT NULL DEFAULT '',
  LoginMethodID INT4 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE margin_id_seq;

CREATE TABLE margin (
  ID INT4 DEFAULT nextval('margin_id_seq'),
  marginID INT4 NOT NULL DEFAULT '0',
  name varchar(32) NOT NULL DEFAULT '',
  margin float NOT NULL DEFAULT '0',
  productcollID INT4 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE margincollection_id_seq;

CREATE TABLE margincollection (
  ID INT4 DEFAULT nextval('margincollection_id_seq'),
  margincollID INT4 NOT NULL DEFAULT '0',
  name varchar(32) NOT NULL DEFAULT '',
  type INT4 NOT NULL DEFAULT '0',
  marginID INT4 NOT NULL DEFAULT '0',
  sitecollID INT4 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE menu_id_seq;

CREATE TABLE menu (
  ID INT4 DEFAULT nextval('menu_id_seq'),
  cmID INT4 NOT NULL DEFAULT '0',
  name varchar(32) NOT NULL DEFAULT '',
  description varchar(64) NOT NULL DEFAULT '',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE menuheading_id_seq;

CREATE TABLE menuheading (
  ID INT4 DEFAULT nextval('menuheading_id_seq'),
  name varchar(64) NOT NULL DEFAULT '',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE menuitem_id_seq;

CREATE TABLE menuitem (
  ID INT4 DEFAULT nextval('menuitem_id_seq'),
  cmID INT4 NOT NULL DEFAULT '0',
  menuID INT4 NOT NULL DEFAULT '0',
  menuheadingID INT4 NOT NULL DEFAULT '0',
  productID INT4 NOT NULL DEFAULT '0',
  name varchar(32) NOT NULL DEFAULT '',
  description varchar(64) NOT NULL DEFAULT '',
  price FLOAT8 NOT NULL DEFAULT '0',
  printerID INT4 NOT NULL DEFAULT '0',
  rectext varchar(32) NOT NULL DEFAULT '',
  available char(1) NOT NULL DEFAULT 'Y',
  PRIMARY KEY (ID),
  CHECK (available='N' OR available='Y')
);

-- --------------------------------------------------------

CREATE SEQUENCE menuitemoptions_id_seq;

CREATE TABLE menuitemoptions (
  ID INT4 DEFAULT nextval('menuitemoptions_id_seq'),
  cmID INT4 NOT NULL DEFAULT '0',
  name varchar(64) NOT NULL DEFAULT '',
  description varchar(64) NOT NULL DEFAULT '',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE menuschedule_id_seq;

CREATE TABLE menuschedule (
  ID INT4 DEFAULT nextval('menuschedule_id_seq'),
  menuID INT4 NOT NULL DEFAULT '0',
  cmID INT4 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE mismenu_id_seq;

CREATE TABLE mismenu (
  ID INT4 DEFAULT nextval('mismenu_id_seq'),
  ParentID INT4 NOT NULL DEFAULT '0',
  SortOrder INT4 NOT NULL DEFAULT '0',
  Name varchar(64) NOT NULL DEFAULT '',
  Module varchar(80) NOT NULL DEFAULT '',
  BaseDir varchar(80) NOT NULL DEFAULT '',
  PHPFile varchar(80) NOT NULL DEFAULT '',
  Action varchar(80) NOT NULL DEFAULT '',
  ImageFile varchar(128) NOT NULL DEFAULT '',
  Type INT4 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE mismenuauth_id_seq;

CREATE TABLE mismenuauth (
  ID INT4 DEFAULT nextval('mismenuauth_id_seq'),
  MenuID INT4 NOT NULL DEFAULT '0',
  InterfaceID INT4 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE mismodule_id_seq;

CREATE TABLE mismodule (
  ID INT4 DEFAULT nextval('mismodule_id_seq'),
  Name varchar(80) NOT NULL DEFAULT '',
  Title varchar(255) NOT NULL DEFAULT '',
  Author varchar(255) NOT NULL DEFAULT '',
  Created TIMESTAMP NOT NULL DEFAULT '0001-01-01 00:00:00',
  Description varchar(255) NOT NULL DEFAULT '',
  Enabled char(1) NOT NULL DEFAULT 'N', 
  MenuID INT4 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID),
  CHECK (Enabled='N' OR Enabled='Y' OR Enabled='S')
);

-- --------------------------------------------------------

CREATE SEQUENCE monetaryunits_id_seq;

CREATE TABLE monetaryunits (
  ID INT4 DEFAULT nextval('monetaryunits_id_seq'),
  muID INT4 NOT NULL DEFAULT '0',
  Unit INT2 NOT NULL DEFAULT '0',
  Value float NOT NULL DEFAULT '0',
  lowamount INT4 NOT NULL DEFAULT '0',
  highamount INT4 NOT NULL DEFAULT '0',
  DefAmount INT4 NOT NULL DEFAULT '20',
  DefRound char(1) NOT NULL DEFAULT 'N',
  PRIMARY KEY (ID),
  CHECK (DefRound='N' OR DefRound='Y')
);

-- --------------------------------------------------------

CREATE SEQUENCE nirates_id_seq;

CREATE TABLE nirates (
  ID INT4 DEFAULT nextval('nirates_id_seq'),
  name char(16) NOT NULL DEFAULT '',
  EmployeeRate DECIMAL(6,2) NOT NULL DEFAULT '0.00',
  EmployerRate DECIMAL(6,2) NOT NULL DEFAULT '0.00',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE orderitems_id_seq;

CREATE TABLE orderitems (
  ID INT4 DEFAULT nextval('orderitems_id_seq'),
  orderID INT4 NOT NULL DEFAULT '0',
  ProductID INT4 NOT NULL DEFAULT '0',
  Quantity INT4 NOT NULL DEFAULT '1',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE orders_id_seq;

CREATE TABLE orders (
  ID INT4 DEFAULT nextval('orders_id_seq'),
  orderID INT4 NOT NULL DEFAULT '0',
  OrderNumber varchar(64) NOT NULL DEFAULT '',
  CustomerID INT4 NOT NULL DEFAULT '0',
  StatusID INT4 NOT NULL DEFAULT '0',
  DatePlaced DATE NOT NULL DEFAULT '0001-01-01',
  DateRequired DATE NOT NULL DEFAULT '0001-01-01',
  BilledDate DATE NOT NULL DEFAULT '0001-01-01',
  ShippedDate DATE NOT NULL DEFAULT '0001-01-01',
  SubTotal DECIMAL(6,2) NOT NULL DEFAULT '0.00',
  ShipCost DECIMAL(6,2) NOT NULL DEFAULT '0.00',
  Tax DECIMAL(6,2) NOT NULL DEFAULT '0.00',
  Total DECIMAL(6,2) NOT NULL DEFAULT '0.00',
  baseCurrencyID INT4 NOT NULL DEFAULT '0',
  accountID INT4 NOT NULL DEFAULT '0',
  TransactionID INT4 NOT NULL DEFAULT '0',
  shippingID INT4 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE paygrades_id_seq;

CREATE TABLE paygrades (
  ID INT4 DEFAULT nextval('paygrades_id_seq'),
  name char(16) NOT NULL DEFAULT '',
  NumIcrements INT4 NOT NULL DEFAULT '0',
  Minimum DECIMAL(6,2) NOT NULL DEFAULT '0.00',
  Maximum DECIMAL(6,2) NOT NULL DEFAULT '0.00',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE paymentdetails_id_seq;

CREATE TABLE paymentdetails (
  ID INT4 DEFAULT nextval('paymentdetails_id_seq'),
  Reference varchar(64) NOT NULL DEFAULT '',
  ExtraData varchar(128) NOT NULL DEFAULT '',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE paymentitem_id_seq;

CREATE TABLE paymentitem (
  ID INT4 DEFAULT nextval('paymentitem_id_seq'),
  PayID INT4  NOT NULL DEFAULT '0',
  transID INT4  NOT NULL DEFAULT '0',
  payType INT2 NOT NULL DEFAULT '1',
  amount FLOAT8 NOT NULL DEFAULT '0',
  EnteredAt timestamp NOT NULL,
  EnteredBy INT4 NOT NULL DEFAULT '0',
  EnteredStation char(20) NOT NULL DEFAULT '',
  PaymentDetailsID INT4 NOT NULL DEFAULT '1',
  PRIMARY KEY (ID),
  CHECK (PayID>=0),
  CHECK (transID>=0)
);

-- --------------------------------------------------------

CREATE SEQUENCE paymentterms_id_seq;

CREATE TABLE paymentterms (
  ID INT4 DEFAULT nextval('paymentterms_id_seq'),
  name char(32) NOT NULL DEFAULT '',
  days INT4 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE paymenttype_id_seq;

CREATE TABLE paymenttype (
  ID INT4 DEFAULT nextval('paymenttype_id_seq'),
  GroupPtrID INT4 NOT NULL DEFAULT '0',
  name varchar(32) NOT NULL DEFAULT '',
  cashback char(1) NOT NULL DEFAULT 'N',
  cashbacklimit float NOT NULL DEFAULT '0',
  bAcceptable char(1) NOT NULL DEFAULT 'Y',
  PRIMARY KEY (ID),
  CHECK (bAcceptable='N' OR bAcceptable='Y')
);

-- --------------------------------------------------------

CREATE SEQUENCE plu_cache_id_seq;

CREATE TABLE plu_cache (
  ID INT4 DEFAULT nextval('plu_cache_id_seq'),
  ProductID INT4 NOT NULL DEFAULT '0',
  nameID INT4 NOT NULL DEFAULT '1',
  PLU varchar(16) NOT NULL DEFAULT '',
  DispText varchar(64) NOT NULL DEFAULT '',
  RecuText varchar(32) NOT NULL DEFAULT '',
  UnitPrice float NOT NULL DEFAULT '0',
  Discount float NOT NULL DEFAULT '0',
  depositType INT4 NOT NULL DEFAULT '0',
  Deposit float NOT NULL DEFAULT '0',
  Tax float NOT NULL DEFAULT '0',
  ItemFlags INT4  NOT NULL DEFAULT '0',
  PRIMARY KEY (ID),
  CHECK (ItemFlags>=0)
);

-- --------------------------------------------------------

CREATE TABLE postaction (
  ID INT4 NOT NULL DEFAULT '0',
  action varchar(32) NOT NULL DEFAULT '',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE postinterface_id_seq;

CREATE TABLE postinterface (
  ID INT4 DEFAULT nextval('postinterface_id_seq'),
  PostID INT4 NOT NULL DEFAULT '0',
  InterfaceID INT4 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE postlog_id_seq;

CREATE TABLE postlog (
  ID INT4 DEFAULT nextval('postlog_id_seq'),
  postID INT4 NOT NULL DEFAULT '0',
  actionID INT4 NOT NULL DEFAULT '0',
  stamper timestamp NOT NULL,
  data varchar(32) NOT NULL DEFAULT '',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE posts_id_seq;

CREATE TABLE posts (
  ID INT4 DEFAULT nextval('posts_id_seq'),
  name varchar(32) NOT NULL DEFAULT '',
  mac varchar(12) NOT NULL DEFAULT '0',
  groupID INT4 NOT NULL DEFAULT '0',
  localeID INT4 NOT NULL DEFAULT '270',
  currencyID INT4 NOT NULL DEFAULT '270',
  Active char(1) NOT NULL DEFAULT 'N',
  PRIMARY KEY (ID),
  CHECK (Active='N' OR Active='Y')
);

-- --------------------------------------------------------

CREATE SEQUENCE pqname_id_seq;

CREATE TABLE pqname (
  ID INT4 DEFAULT nextval('pqname_id_seq'),
  name varchar(64) NOT NULL DEFAULT '',
  accountID INT4 NOT NULL DEFAULT '0',
  OnMenu char(1) NOT NULL DEFAULT 'N',
  PRIMARY KEY (ID),
  CHECK (OnMenu='N' OR OnMenu='Y')
);

-- --------------------------------------------------------

CREATE SEQUENCE prescription_id_seq;

CREATE TABLE prescription (
  ID INT4 DEFAULT nextval('prescription_id_seq'),
  prescriptionID INT4 NOT NULL DEFAULT '0',
  cmID INT4 NOT NULL DEFAULT '0',
  transactionID INT4 NOT NULL DEFAULT '0',
  prescriptionNumber varchar(32) NOT NULL DEFAULT '',
  readiedbyID INT4 NOT NULL DEFAULT '0',
  readiedAt timestamp NOT NULL,
  insurerID INT4 NOT NULL DEFAULT '0',
  customerID INT4 NOT NULL DEFAULT '0',
  signatureID INT4 NOT NULL DEFAULT '0',
  refill char(1) NOT NULL DEFAULT 'N',
  refillnumber INT4 NOT NULL DEFAULT '0',
  numrefills INT4 NOT NULL DEFAULT '0',
  prescribedamount INT4 NOT NULL DEFAULT '0',
  prescribeddays INT4 NOT NULL DEFAULT '0',
  daysupply INT4 NOT NULL DEFAULT '0',
  generatedSite INT4 NOT NULL DEFAULT '0',
  willCollect char(1) NOT NULL DEFAULT 'Y',
  collectedSite INT4 NOT NULL DEFAULT '0',
  collectedWhen timestamp NOT NULL,
  status INT4 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID),
  CHECK (transactionID>=0),
  CHECK (refill='N' OR refill='Y'),
  CHECK (willCollect='N' OR willCollect='Y')
);

-- --------------------------------------------------------

CREATE SEQUENCE prescriptionitems_id_seq;

CREATE TABLE prescriptionitems (
  ID INT4 DEFAULT nextval('prescriptionitems_id_seq'),
  prescriptionID INT4 NOT NULL DEFAULT '0',
  dispenseddate DATE NOT NULL DEFAULT '0001-01-01',
  productID INT4 NOT NULL DEFAULT '0',
  barcodeID INT4 NOT NULL DEFAULT '0',
  quantity INT4 NOT NULL DEFAULT '0',
  safetycap char(1) NOT NULL DEFAULT 'Y',
  labelID INT4 NOT NULL DEFAULT '0',
  cautionID INT4 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID),
  CHECK (safetycap='N' OR safetycap='Y')
);

-- --------------------------------------------------------

CREATE SEQUENCE printer_id_seq;

CREATE TABLE printer (
  ID INT4 DEFAULT nextval('printer_id_seq'),
  name varchar(32) NOT NULL DEFAULT '',
  description varchar(64) NOT NULL DEFAULT '',
  address varchar(128) NOT NULL DEFAULT '',
  port varchar(5) NOT NULL DEFAULT '',
  active char(1) NOT NULL DEFAULT 'N',
  PRIMARY KEY (ID),
  CHECK (active='N' OR active='Y')
);

-- --------------------------------------------------------

CREATE TABLE printsheet (
  ID INT4 NOT NULL DEFAULT '0',
  name varchar(32) NOT NULL DEFAULT '',
  xsize INT4 NOT NULL DEFAULT '0',
  ysize INT4 NOT NULL DEFAULT '0',
  left_margin INT4 NOT NULL DEFAULT '0',
  right_margin INT4 NOT NULL DEFAULT '0',
  top_margin INT4 NOT NULL DEFAULT '0',
  bottom_margin INT4 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE prodpricequantity_id_seq;

CREATE TABLE prodpricequantity (
  ID INT4 DEFAULT nextval('prodpricequantity_id_seq'),
  pqID INT4 NOT NULL DEFAULT '0',
  nameID INT4 NOT NULL DEFAULT '1',
  Quantity INT4 NOT NULL DEFAULT '1',
  QuantityTypeID INT4 NOT NULL DEFAULT '0',
  UDV INT4 NOT NULL DEFAULT '1',
  Price DECIMAL(14,4) NOT NULL DEFAULT '0.0000',
  baseCurrencyID INT4 NOT NULL DEFAULT '0',
  TaxID INT4 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE prodtarget_id_seq;

CREATE TABLE prodtarget (
  ID INT4 DEFAULT nextval('prodtarget_id_seq'),
  cmid INT4 NOT NULL DEFAULT '0',
  productID INT4 NOT NULL DEFAULT '0',
  periodType INT4 NOT NULL DEFAULT '0',
  period INT4 NOT NULL DEFAULT '0',
  targetType INT4 NOT NULL DEFAULT '0',
  target varchar(16) NOT NULL DEFAULT '0',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE product_id_seq;

CREATE TABLE product (
  ID INT4 DEFAULT nextval('product_id_seq'),
  ProductID INT4  NOT NULL DEFAULT '0',
  InvID INT4 NOT NULL DEFAULT '0',
  categoryID INT4 NOT NULL DEFAULT '0',
  accountID INT4 NOT NULL DEFAULT '0',
  PLU varchar(128) NOT NULL DEFAULT '',
  PLUType INT4 NOT NULL DEFAULT '0',
  Name varchar(64) NOT NULL DEFAULT 'No Name',
  Description varchar(128) NOT NULL DEFAULT 'No Description',
  InStock INT4 NOT NULL DEFAULT '0',
  Discontinued char(1) NOT NULL DEFAULT 'N',
  ImageID INT4 NOT NULL DEFAULT '0',
  RecieptText varchar(64) NOT NULL DEFAULT 'No Name',
  labelID INT4 NOT NULL DEFAULT '0',
  SellQuantityID INT4 NOT NULL DEFAULT '0',
  discountID INT4 NOT NULL DEFAULT '0',
  PromotionID INT4 NOT NULL DEFAULT '1',
  rentable char(1) NOT NULL DEFAULT 'N',
  depositID INT4 NOT NULL DEFAULT '0',
  eCommerce char(1) NOT NULL DEFAULT 'N',
  flags INT4  NOT NULL DEFAULT '0',
  productLink INT4 NOT NULL DEFAULT '0',
  Keywords varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (ID),
  CHECK (ProductID>=0),
  CHECK (flags>=0),
  CHECK (Discontinued='N' OR Discontinued='Y'),
  CHECK (rentable='N' OR rentable='Y'),
  CHECK (eCommerce='N' OR eCommerce='Y')
);

-- --------------------------------------------------------

CREATE TABLE productcategory (
  productID INT4 NOT NULL DEFAULT '0',
  categoryID INT4 NOT NULL DEFAULT '0'
);

-- --------------------------------------------------------

CREATE TABLE productcollection (
  prodcollID INT4 NOT NULL DEFAULT '0',
  productID INT4 NOT NULL DEFAULT '0'
);

-- --------------------------------------------------------

CREATE SEQUENCE promotion_id_seq;

CREATE TABLE promotion (
  ID INT4 DEFAULT nextval('promotion_id_seq'),
  promotionID INT4 NOT NULL DEFAULT '0',
  type INT4 NOT NULL DEFAULT '0',
  StartDate timestamp NOT NULL,
  EndDate timestamp NOT NULL,
  Margin DECIMAL(6,2) NOT NULL DEFAULT '0.00',
  Memo varchar(64) NOT NULL DEFAULT '',
  promoLinkID INT4 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE purchaseorder_id_seq;

CREATE TABLE purchaseorder (
  ID INT4 DEFAULT nextval('purchaseorder_id_seq'),
  purchaseorderID INT4 NOT NULL DEFAULT '0',
  purchaseNumber varchar(64) NOT NULL DEFAULT '',
  statusID INT4 NOT NULL DEFAULT '0',
  name varchar(64) NOT NULL DEFAULT '',
  cmID INT4 NOT NULL DEFAULT '0',
  dispatchDate DATE NOT NULL DEFAULT '0001-01-01',
  arrivedDate DATE NOT NULL DEFAULT '0001-01-01',
  supplierID INT4 NOT NULL DEFAULT '0',
  shippingID INT4 NOT NULL DEFAULT '0',
  requestedBy INT4 NOT NULL DEFAULT '0',
  approvedBy INT4 NOT NULL DEFAULT '0',
  accountID INT4 NOT NULL DEFAULT '0',
  transactionID INT4 NOT NULL DEFAULT '0',
  linkID INT4 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID),
  CHECK (purchaseorderID>=0)
);

-- --------------------------------------------------------

CREATE SEQUENCE purchaseorderitems_id_seq;

CREATE TABLE purchaseorderitems (
  ID INT4 DEFAULT nextval('purchaseorderitems_id_seq'),
  PurchaseOrderID INT4 NOT NULL DEFAULT '0',
  Quantity INT4 NOT NULL DEFAULT '1',
  InventoryID INT4 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE rec_stock_id_seq;

CREATE TABLE rec_stock (
  ID INT4 DEFAULT nextval('rec_stock_id_seq'),
  invID INT4 NOT NULL DEFAULT '0',
  PLU varchar(16) NOT NULL DEFAULT '',
  Sold INT4 NOT NULL DEFAULT '0',
  Returned INT4 NOT NULL DEFAULT '0',
  Recieved INT4 NOT NULL DEFAULT '0',
  TransferIn INT4 NOT NULL DEFAULT '0',
  TransferOut INT4 NOT NULL DEFAULT '0',
  Out INT4 NOT NULL DEFAULT '0',
  StocklevelWarning INT4 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE rental_id_seq;

CREATE TABLE rental (
  ID INT4 DEFAULT nextval('rental_id_seq'),
  transactionID INT4 NOT NULL DEFAULT '0',
  customerID INT4 NOT NULL DEFAULT '0',
  rentedfromID INT4 NOT NULL DEFAULT '0',
  rentedOn timestamp NOT NULL,
  duration INT4 NOT NULL DEFAULT '0',
  returned char(1) NOT NULL DEFAULT 'N',
  returnedtoID INT4 NOT NULL DEFAULT '0',
  returnedAt timestamp NOT NULL,
  PRIMARY KEY (ID),
  CHECK (returned='N' OR returned='Y')
);

-- --------------------------------------------------------

CREATE SEQUENCE rentalitems_id_seq;

CREATE TABLE rentalitems (
  ID INT4 DEFAULT nextval('rentalitems_id_seq'),
  rentalID INT4 NOT NULL DEFAULT '0',
  productID INT4 NOT NULL DEFAULT '0',
  quantity INT4 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE reservation_id_seq;

CREATE TABLE reservation (
  ID INT4 DEFAULT nextval('reservation_id_seq'),
  reservationID INT4 NOT NULL DEFAULT '0',
  cmID INT4 NOT NULL DEFAULT '0',
  refID INT4 NOT NULL DEFAULT '0',
  sdate DATE NOT NULL DEFAULT '0001-01-01',
  edate DATE NOT NULL DEFAULT '0001-01-01',
  type INT4 NOT NULL DEFAULT '0',
  notes varchar(64) NOT NULL DEFAULT '0',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE TABLE reservationref (
  refID INT4 NOT NULL DEFAULT '0',
  reservationID INT4 NOT NULL DEFAULT '0'
);

-- --------------------------------------------------------

CREATE SEQUENCE reservationtype_id_seq;

CREATE TABLE reservationtype (
  ID INT4 DEFAULT nextval('reservationtype_id_seq'),
  name varchar(64) NOT NULL DEFAULT '',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE return_id_seq;

CREATE TABLE return (
  ID INT4 DEFAULT nextval('return_id_seq'),
  transID INT4 NOT NULL DEFAULT '0',
  type INT4 NOT NULL DEFAULT '0',
  destination INT4 NOT NULL DEFAULT '0',
  todestAt timestamp NOT NULL,
  todestBy INT4 NOT NULL DEFAULT '0',
  reasonID INT2 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE returnreason_id_seq;

CREATE TABLE returnreason (
  ID INT4 DEFAULT nextval('returnreason_id_seq'),
  transID INT4 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE returntype_id_seq;

CREATE TABLE returntype (
  ID INT4 DEFAULT nextval('returntype_id_seq'),
  Name varchar(64) NOT NULL DEFAULT '',
  Active char(1) NOT NULL DEFAULT 'N',
  PRIMARY KEY (ID),
  CHECK (Active='N' OR Active='Y')
);

-- --------------------------------------------------------

CREATE SEQUENCE rxcaution_id_seq;

CREATE TABLE rxcaution (
  ID INT4 DEFAULT nextval('rxcaution_id_seq'),
  cautionID INT4 NOT NULL DEFAULT '0',
  name varchar(32) NOT NULL DEFAULT '0',
  data varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE servicecontract_id_seq;

CREATE TABLE servicecontract (
  ID INT4 DEFAULT nextval('servicecontract_id_seq'),
  custID INT4 NOT NULL DEFAULT '0',
  typeID INT4 NOT NULL DEFAULT '0',
  startdate DATE NOT NULL DEFAULT '0001-01-01',
  enddate DATE NOT NULL DEFAULT '0001-01-01',
  price DECIMAL(6,2) NOT NULL DEFAULT '0.00',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE TABLE setup (
  ID INT4 NOT NULL DEFAULT '0',
  name varchar(255) NOT NULL DEFAULT '"No Name"',
  accountingDate DATE NOT NULL DEFAULT '0001-01-01',
  regNumber varchar(64) NOT NULL DEFAULT '',
  vatNumber varchar(64) NOT NULL DEFAULT '',
  cmID INT4 NOT NULL DEFAULT '0',
  siteID INT4 NOT NULL DEFAULT '0',
  IsMaster char(1) NOT NULL DEFAULT 'N',
  Master varchar(64) NOT NULL DEFAULT '',
  ConnectMethod INT4 NOT NULL DEFAULT '0',
  ConnectData varchar(255) NOT NULL DEFAULT '',
  ConnectLogin varchar(64) NOT NULL DEFAULT '',
  ConnectPassword varchar(64) NOT NULL DEFAULT '',
  ConnectTime time NOT NULL DEFAULT '00:00:00',
  PRIMARY KEY (ID),
  CHECK (IsMaster='N' OR IsMaster='Y')
);

-- --------------------------------------------------------

CREATE SEQUENCE shipcarrier_id_seq;

CREATE TABLE shipcarrier (
  ID INT4 DEFAULT nextval('shipcarrier_id_seq'),
  name char(32) NOT NULL DEFAULT '',
  autoupdate char(1) NOT NULL DEFAULT 'N',
  PRIMARY KEY (ID),
  CHECK (autoupdate='N' OR autoupdate='Y')
);

-- --------------------------------------------------------

CREATE SEQUENCE shipping_id_seq;

CREATE TABLE shipping (
  ID INT4 DEFAULT nextval('shipping_id_seq'),
  shipNumber varchar(64) NOT NULL DEFAULT '',
  carrierID INT4 NOT NULL DEFAULT '0',
  rateID INT4 NOT NULL DEFAULT '0',
  cmID INT4 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE shiprate_id_seq;

CREATE TABLE shiprate (
  ID INT4 DEFAULT nextval('shiprate_id_seq'),
  unitName char(32) NOT NULL DEFAULT '',
  lowerbound FLOAT8 NOT NULL DEFAULT '0',
  upperbound FLOAT8 NOT NULL DEFAULT '0',
  unitRate FLOAT8 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE signature_id_seq;

CREATE TABLE signature (
  ID INT4 DEFAULT nextval('signature_id_seq'),
  signatureID INT4 NOT NULL DEFAULT '0',
  cmID INT4 NOT NULL DEFAULT '0',
  category varchar(32) NOT NULL DEFAULT '',
  xdim INT4 NOT NULL DEFAULT '0',
  ydim INT4 NOT NULL DEFAULT '0',
  typeID INT4 NOT NULL DEFAULT '0',
  fileref varchar(255) NOT NULL DEFAULT '',
  validuntil DATE NOT NULL DEFAULT '0001-01-01',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE signaturerefcount_id_seq;

CREATE TABLE signaturerefcount (
  ID INT4 DEFAULT nextval('signaturerefcount_id_seq'),
  signatureID INT4 NOT NULL DEFAULT '0',
  signedAt timestamp NOT NULL,
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE signaturetype_id_seq;

CREATE TABLE signaturetype (
  ID INT4 DEFAULT nextval('signaturetype_id_seq'),
  typeID INT4 NOT NULL DEFAULT '0',
  name varchar(32) NOT NULL DEFAULT '',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE sites_id_seq;

CREATE TABLE sites (
  ID INT4 DEFAULT nextval('sites_id_seq'),
  siteID INT4 NOT NULL DEFAULT '0',
  name varchar(64) NOT NULL DEFAULT '',
  addressID INT4 NOT NULL DEFAULT '0',
  contactID INT4 NOT NULL DEFAULT '0',
  localeID INT4 NOT NULL DEFAULT '0',
  currencyID INT4 NOT NULL DEFAULT '270',
  bankID INT4 NOT NULL DEFAULT '0',
  AnnualBudget float NOT NULL DEFAULT '0',
  site varchar(255) NOT NULL DEFAULT '',
  encryption varchar(255) NOT NULL DEFAULT '',
  login varchar(64) NOT NULL DEFAULT '',
  password varchar(64) NOT NULL DEFAULT '',
  Active char(1) NOT NULL DEFAULT 'N',
  PRIMARY KEY (ID),
  CHECK (Active='N' OR Active='Y')
);

-- --------------------------------------------------------

CREATE SEQUENCE status_id_seq;

CREATE TABLE status (
  ID INT4 DEFAULT nextval('status_id_seq'),
  Name char(32) NOT NULL DEFAULT '',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE storecard_id_seq;

CREATE TABLE storecard (
  ID INT4 DEFAULT nextval('storecard'),
  cardID varchar(16) NOT NULL DEFAULT '',
  custID INT4 NOT NULL DEFAULT '0',
  discountID INT4 NOT NULL DEFAULT '0',
  barcode varchar(128) NOT NULL DEFAULT '0',
  swipedata varchar(128) NOT NULL DEFAULT '0',
  writable char(1) NOT NULL DEFAULT 'N',
  amCurrent FLOAT8 NOT NULL DEFAULT '0',
  amLimit FLOAT8 NOT NULL DEFAULT '0',
  status INT4 NOT NULL DEFAULT '0',
  notes varchar(64) NOT NULL DEFAULT '',
  PRIMARY KEY (ID),
  CHECK (writable='N' OR writable='Y')
);

-- --------------------------------------------------------

CREATE SEQUENCE supplier_id_seq;

CREATE TABLE supplier (
  ID INT4 DEFAULT nextval('supplier_id_seq'),
  cmdID INT4 NOT NULL DEFAULT '0',
  supplierID varchar(32) NOT NULL DEFAULT '',
  typeID INT4 NOT NULL DEFAULT '0',
  name varchar(64) NOT NULL DEFAULT '',
  addressID INT4 NOT NULL DEFAULT '0',
  invoiceName varchar(64) NOT NULL DEFAULT '',
  invoiceContactID INT4 NOT NULL DEFAULT '0',
  contactID INT4 NOT NULL DEFAULT '0',
  chargeID INT4 NOT NULL DEFAULT '0',
  ediID INT4 NOT NULL DEFAULT '0',
  acccountID varchar(32) NOT NULL DEFAULT '0',
  linkID INT4 NOT NULL DEFAULT '0',
  type INT4 NOT NULL DEFAULT '0',
  Active char(1) NOT NULL DEFAULT 'N',
  notes TEXT DEFAULT '' NOT NULL,
  PRIMARY KEY (ID),
  CHECK (Active='N' OR Active='Y')
);

-- --------------------------------------------------------

CREATE SEQUENCE suppliertype_id_seq;

CREATE TABLE suppliertype (
  ID INT4 DEFAULT nextval('suppliertype_id_seq'),
  name char(32) NOT NULL DEFAULT '',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE synch_id_seq;

CREATE TABLE synch (
  ID INT4 DEFAULT nextval('synch_id_seq'),
  typeID INT4 NOT NULL DEFAULT '0',
  CreationDate timestamp NOT NULL,
  ModifiedDate timestamp NOT NULL,
  ImplementationAt timestamp NOT NULL,
  Implemented char(1) NOT NULL DEFAULT 'N',
  PRIMARY KEY (ID),
  CHECK (Implemented='N' OR Implemented='Y')
);

-- --------------------------------------------------------

CREATE SEQUENCE synchtype_id_seq;

CREATE TABLE synchtype (
  ID INT4 DEFAULT nextval('synchtype_id_seq'),
  name char(32) NOT NULL DEFAULT '',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE tabler_id_seq;

CREATE TABLE tabler (
  ID INT4 DEFAULT nextval('tabler_id_seq'),
  name varchar(32) NOT NULL DEFAULT '',
  description varchar(64) NOT NULL DEFAULT '',
  capacity INT4 NOT NULL DEFAULT '0',
  Notes varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE taxrate_id_seq;

CREATE TABLE taxrate (
  ID INT4 DEFAULT nextval('taxrate_id_seq'),
  TaxID INT4 NOT NULL DEFAULT '0',
  accountID INT4 NOT NULL DEFAULT '0',
  Rate DECIMAL(7,5) NOT NULL DEFAULT '0.00000',
  OnMenu char(1) NOT NULL DEFAULT 'N',
  PRIMARY KEY (ID),
  CHECK (OnMenu='N' OR OnMenu='Y')
);

-- --------------------------------------------------------

CREATE SEQUENCE transaction_id_seq;

CREATE TABLE transaction (
  ID INT4 DEFAULT nextval('transaction_id_seq'),
  transactionID INT4 NOT NULL DEFAULT '0',
  EnteredAt timestamp NOT NULL,
  EnteredBy INT4 NOT NULL DEFAULT '0',
  EnteredStation varchar(20) NOT NULL DEFAULT '',
  StatusID INT4 NOT NULL DEFAULT '15',
  PaymentTypeID INT4 NOT NULL DEFAULT '0',
  RefNum varchar(32) NOT NULL DEFAULT '',
  Description varchar(64) NOT NULL DEFAULT '',
  Open char(1) NOT NULL DEFAULT 'Y',
  Reconciled char(1) NOT NULL DEFAULT 'N',
  Taxable char(1) NOT NULL DEFAULT 'Y',
  settlementID INT4  NOT NULL DEFAULT '0',
  linkID INT4  NOT NULL DEFAULT '0',
  PRIMARY KEY (ID),
  CHECK (transactionID>=0),
  CHECK (settlementID>=0),
  CHECK (linkID>=0),
  CHECK (Reconciled='N' OR Reconciled='Y'),
  CHECK (Open='N' OR Open='Y'),
  CHECK (Taxable='N' OR Taxable='Y')
);

-- --------------------------------------------------------

CREATE SEQUENCE transactionitems_id_seq;

CREATE TABLE transactionitems (
  ID INT4 DEFAULT nextval('transactionitems_id_seq'),
  transactionID INT4 NOT NULL DEFAULT '0',
  EnteredAt timestamp NOT NULL,
  EnteredBy INT4 NOT NULL DEFAULT '0',
  EnteredStation varchar(20) NOT NULL DEFAULT '',
  type INT4 NOT NULL DEFAULT '2',
  PLU varchar(128) NOT NULL DEFAULT '0000000000000',
  quantity INT4 NOT NULL DEFAULT '1',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE transtype_id_seq;

CREATE TABLE transtype (
  ID INT4 DEFAULT nextval('transtype_id_seq'),
  transID INT4 NOT NULL DEFAULT '0',
  type INT4 NOT NULL DEFAULT '0',
  data varchar(32) NOT NULL DEFAULT '',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE u_plu_id_seq;

CREATE TABLE u_plu (
  ID INT4 DEFAULT nextval('u_plu_id_seq'),
  entryat timestamp NOT NULL,
  PLU varchar(128) NOT NULL DEFAULT '',
  PLUType INT4 NOT NULL DEFAULT '0',
  Name varchar(64) NOT NULL DEFAULT 'No Name',
  UnitPrice FLOAT8 NOT NULL DEFAULT '0',
  Discount float NOT NULL DEFAULT '0',
  Tax float NOT NULL DEFAULT '0',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE userauth_id_seq;

CREATE TABLE userauth (
  ID INT4 DEFAULT nextval('userauth_id_seq'),
  UserID INT4 NOT NULL DEFAULT '0',
  AuthID INT4 NOT NULL DEFAULT '1',
  InterfaceID INT4 NOT NULL DEFAULT '0',
  GroupID INT4 NOT NULL DEFAULT '0',
  LoginMethodID INT4 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE users_id_seq;

CREATE TABLE users (
  ID INT4 DEFAULT nextval('users_id_seq'),
  Login varchar(16) NOT NULL DEFAULT '',
  Password varchar(16) NOT NULL DEFAULT '',
  userData varchar(255) NOT NULL DEFAULT '',
  Profile varchar(255) NOT NULL DEFAULT '',
  LoginTypesID INT4 NOT NULL DEFAULT '0',
  EmployeeID INT4 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID)
);

-- --------------------------------------------------------

CREATE SEQUENCE voucher_id_seq;

CREATE TABLE voucher (
  ID INT4 DEFAULT nextval('voucher_id_seq'),
  voucherID varchar(16) NOT NULL DEFAULT '',
  PLU varchar(128) NOT NULL DEFAULT '',
  enddate DATE NOT NULL DEFAULT '0001-01-01',
  used char(1) NOT NULL DEFAULT 'N',
  type INT4 NOT NULL DEFAULT '0',
  Margin FLOAT8 NOT NULL DEFAULT '0',
  productLinkID INT4 NOT NULL DEFAULT '0',
  PRIMARY KEY (ID),
  CHECK (used='N' OR used='Y')
);

CREATE INDEX transidx_transactionitems_index ON transactionitems (transactionID);
CREATE INDEX UserID_userauth_index ON userauth (UserID);
CREATE INDEX Name_mismodule_index ON mismodule (Name);
CREATE UNIQUE INDEX AccountNumber_account_index ON account (AccountNumber);
CREATE UNIQUE INDEX PLU_rec_stock_index ON rec_stock (PLU);
CREATE INDEX ID_errorlog_index ON errorlog (ID);
CREATE INDEX MenuID_mismenuauth_index ON mismenuauth (MenuID);
CREATE UNIQUE INDEX PLU_ephemeral_plu_index ON ephemeral_plu (PLU);
CREATE UNIQUE INDEX ID_ephemeral_plu_index ON ephemeral_plu (ID);
CREATE UNIQUE INDEX PLU_u_plu_index ON u_plu (PLU);
CREATE INDEX promotionID_promotion_index ON promotion (promotionID);
CREATE UNIQUE INDEX AccountNumber_gaccref_index ON gaccref (AccountNumber);
CREATE INDEX transidx_transaction_index ON transaction (transactionID);
CREATE INDEX ParentID_mismenu_index ON mismenu (ParentID,SortOrder);
CREATE UNIQUE INDEX PLU_product_index ON product (PLU);
CREATE INDEX purchaseorderID_purchaseorder_index ON purchaseorder (purchaseorderID);

SELECT SETVAL('delivery_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from delivery));
SELECT SETVAL('paygrades_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from paygrades));
SELECT SETVAL('transtype_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from transtype));
SELECT SETVAL('logintypes_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from logintypes));
SELECT SETVAL('insurer_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from insurer));
SELECT SETVAL('posts_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from posts));
SELECT SETVAL('category_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from category));
SELECT SETVAL('shipping_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from shipping));
SELECT SETVAL('orderitems_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from orderitems));
SELECT SETVAL('servicecontract_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from servicecontract));
SELECT SETVAL('contactdetails_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from contactdetails));
SELECT SETVAL('paymentdetails_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from paymentdetails));
SELECT SETVAL('course_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from course));
SELECT SETVAL('imagedata_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from imagedata));
SELECT SETVAL('paymentterms_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from paymentterms));
SELECT SETVAL('custcallhistory_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from custcallhistory));
SELECT SETVAL('tabler_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from tabler));
SELECT SETVAL('createmod_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from createmod));
SELECT SETVAL('goodstransfer_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from goodstransfer));
SELECT SETVAL('bqname_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from bqname));
SELECT SETVAL('paymenttype_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from paymenttype));
SELECT SETVAL('discreetdiscount_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from discreetdiscount));
SELECT SETVAL('invpricequantity_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from invpricequantity));
SELECT SETVAL('bankdetails_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from bankdetails));
SELECT SETVAL('printer_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from printer));
SELECT SETVAL('orders_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from orders));
SELECT SETVAL('discrepancy_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from discrepancy));
SELECT SETVAL('pqname_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from pqname));
SELECT SETVAL('users_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from users));
SELECT SETVAL('collection_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from collection));
SELECT SETVAL('menuheading_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from menuheading));
SELECT SETVAL('signaturetype_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from signaturetype));
SELECT SETVAL('adjustment_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from adjustment));
SELECT SETVAL('currency_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from currency));
SELECT SETVAL('paymentitem_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from paymentitem));
SELECT SETVAL('employee_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from employee));
SELECT SETVAL('employeelog_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from employeelog));
SELECT SETVAL('suppliertype_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from suppliertype));
SELECT SETVAL('mismenu_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from mismenu));
SELECT SETVAL('custflags_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from custflags));
SELECT SETVAL('menuitemoptions_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from menuitemoptions));
SELECT SETVAL('adjustmenttype_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from adjustmenttype));
SELECT SETVAL('inventory_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from inventory));
SELECT SETVAL('country_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from country));
SELECT SETVAL('transactionitems_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from transactionitems));
SELECT SETVAL('taxrate_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from taxrate));
SELECT SETVAL('account_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from account));
SELECT SETVAL('returnreason_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from returnreason));
SELECT SETVAL('reservationtype_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from reservationtype));
SELECT SETVAL('loginmethod_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from loginmethod));
SELECT SETVAL('departments_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from departments));
SELECT SETVAL('u_plu_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from u_plu));
SELECT SETVAL('promotion_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from promotion));
SELECT SETVAL('prodpricequantity_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from prodpricequantity));
SELECT SETVAL('prescription_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from prescription));
SELECT SETVAL('prescriptionitems_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from prescriptionitems));
SELECT SETVAL('doctor_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from doctor));
SELECT SETVAL('purchaseorder_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from purchaseorder));
SELECT SETVAL('employeeaction_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from employeeaction));
SELECT SETVAL('shiprate_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from shiprate));
SELECT SETVAL('reservation_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from reservation));
SELECT SETVAL('mismodule_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from mismodule));
SELECT SETVAL('bankitem_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from bankitem));
SELECT SETVAL('custinterventionhistory_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from custinterventionhistory));
SELECT SETVAL('transaction_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from transaction));
SELECT SETVAL('rental_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from rental));
SELECT SETVAL('groups_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from groups));
SELECT SETVAL('interface_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from interface));
SELECT SETVAL('address_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from address));
SELECT SETVAL('synchtype_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from synchtype));
SELECT SETVAL('accountheading_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from accountheading));
SELECT SETVAL('contacts_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from contacts));
SELECT SETVAL('sites_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from sites));
SELECT SETVAL('layby_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from layby));
SELECT SETVAL('mismenuauth_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from mismenuauth));
SELECT SETVAL('nirates_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from nirates));
SELECT SETVAL('bankitemtype_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from bankitemtype));
SELECT SETVAL('signature_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from signature));
SELECT SETVAL('rxcaution_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from rxcaution));
SELECT SETVAL('gaccref_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from gaccref));
SELECT SETVAL('class_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from class));
SELECT SETVAL('label_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from label));
SELECT SETVAL('authority_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from authority));
SELECT SETVAL('plu_cache_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from plu_cache));
SELECT SETVAL('status_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from status));
SELECT SETVAL('synch_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from synch));
SELECT SETVAL('edicaps_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from edicaps));
SELECT SETVAL('errorlog_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from errorlog));
SELECT SETVAL('margincollection_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from margincollection));
SELECT SETVAL('returntype_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from returntype));
SELECT SETVAL('supplier_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from supplier));
SELECT SETVAL('rentalitems_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from rentalitems));
SELECT SETVAL('custhistory_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from custhistory));
SELECT SETVAL('postinterface_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from postinterface));
SELECT SETVAL('faultlog_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from faultlog));
SELECT SETVAL('userauth_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from userauth));
SELECT SETVAL('signaturerefcount_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from signaturerefcount));
SELECT SETVAL('menu_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from menu));
SELECT SETVAL('rec_stock_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from rec_stock));
SELECT SETVAL('purchaseorderitems_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from purchaseorderitems));
SELECT SETVAL('chargeaccount_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from chargeaccount));
SELECT SETVAL('postlog_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from postlog));
SELECT SETVAL('return_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from return));
SELECT SETVAL('ephemeral_plu_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from ephemeral_plu));
SELECT SETVAL('shipcarrier_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from shipcarrier));
SELECT SETVAL('invitemquantitytype_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from invitemquantitytype));
SELECT SETVAL('customer_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from customer));
SELECT SETVAL('goodstransferitem_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from goodstransferitem));
SELECT SETVAL('menuitem_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from menuitem));
SELECT SETVAL('product_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from product));
SELECT SETVAL('margin_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from margin));
SELECT SETVAL('menuschedule_id_seq',(select case when max(ID)>0 then max(ID)+1 else 1 end from menuschedule));

COMMIT;
